@@ -1,6 +1,7 @@
 mod arg_buffer;
 mod async_call;
 mod callback_call;
+mod callback_selector_result;
 mod contract_call;
 mod send_egld;
 mod send_esdt;
@@ -9,6 +10,7 @@ mod send_token;
 pub use arg_buffer::ArgBuffer;
 pub use async_call::AsyncCall;
 pub use callback_call::CallbackCall;
+pub use callback_selector_result::CallbackSelectorResult;
 pub use contract_call::{new_contract_call, ContractCall};
 pub use send_egld::SendEgld;
 pub use send_esdt::SendEsdt;
